"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.bookmarks_api import BookmarksApi  # noqa: E501


class TestBookmarksApi(unittest.TestCase):
    """BookmarksApi unit test stubs"""

    def setUp(self):
        self.api = BookmarksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_bookmark(self):
        """Test case for create_bookmark

        Create a bookmark at the current time.  # noqa: E501
        """
        pass

    def test_create_bookmark_tags(self):
        """Test case for create_bookmark_tags

        Create tags for a Bookmark.  # noqa: E501
        """
        pass

    def test_delete_bookmark(self):
        """Test case for delete_bookmark

        Delete a bookmark.  # noqa: E501
        """
        pass

    def test_delete_bookmark_tags(self):
        """Test case for delete_bookmark_tags

        Delete tags for a Bookmark.  # noqa: E501
        """
        pass

    def test_get_bookmark_by_id(self):
        """Test case for get_bookmark_by_id

        Get a bookmark by ID.  # noqa: E501
        """
        pass

    def test_get_bookmark_tags(self):
        """Test case for get_bookmark_tags

        Get tags for a Bookmark.  # noqa: E501
        """
        pass

    def test_get_bookmarks(self):
        """Test case for get_bookmarks

        List all bookmarks.  # noqa: E501
        """
        pass

    def test_get_vdb_groups_by_bookmark(self):
        """Test case for get_vdb_groups_by_bookmark

        List VDB Groups compatible with this bookmark.  # noqa: E501
        """
        pass

    def test_import_engine_bookmarks(self):
        """Test case for import_engine_bookmarks

        Import engine bookmarks to DCT.  # noqa: E501
        """
        pass

    def test_search_bookmarks(self):
        """Test case for search_bookmarks

        Search for bookmarks.  # noqa: E501
        """
        pass

    def test_search_vdb_groups_by_bookmark(self):
        """Test case for search_vdb_groups_by_bookmark

        Search for VDB Groups compatible with this bookmark.  # noqa: E501
        """
        pass

    def test_update_bookmark(self):
        """Test case for update_bookmark

        Update a bookmark  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.api_client import ApiClient, Endpoint as _Endpoint
from delphix.api.gateway.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from delphix.api.gateway.model.delete_staging_cdb_response import DeleteStagingCDBResponse
from delphix.api.gateway.model.delete_staging_cdb_parameters import DeleteStagingCdbParameters
from delphix.api.gateway.model.delete_tag import DeleteTag
from delphix.api.gateway.model.disable_cdb_parameters import DisableCDBParameters
from delphix.api.gateway.model.disable_staging_cdb_response import DisableStagingCDBResponse
from delphix.api.gateway.model.enable_cdb_parameters import EnableCDBParameters
from delphix.api.gateway.model.enable_staging_cdb_response import EnableStagingCDBResponse
from delphix.api.gateway.model.list_staging_cdbs_response import ListStagingCdbsResponse
from delphix.api.gateway.model.search_body import SearchBody
from delphix.api.gateway.model.search_staging_cdbs_response import SearchStagingCdbsResponse
from delphix.api.gateway.model.staging_cdb import StagingCdb
from delphix.api.gateway.model.tags_request import TagsRequest
from delphix.api.gateway.model.tags_response import TagsResponse


class StagingCdbsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __create_staging_cdb_tags(
            self,
            staging_cdb_id,
            tags_request,
            **kwargs
        ):
            """Create tags for a staging CDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_staging_cdb_tags(staging_cdb_id, tags_request, async_req=True)
            >>> result = thread.get()

            Args:
                staging_cdb_id (str): The Staging CDB ID.
                tags_request (TagsRequest): Tags information for staging CDB.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['staging_cdb_id'] = \
                staging_cdb_id
            kwargs['tags_request'] = \
                tags_request
            return self.call_with_http_info(**kwargs)

        self.create_staging_cdb_tags = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/staging-cdbs/{stagingCdbId}/tags',
                'operation_id': 'create_staging_cdb_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'staging_cdb_id',
                    'tags_request',
                ],
                'required': [
                    'staging_cdb_id',
                    'tags_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'staging_cdb_id':
                        (str,),
                    'tags_request':
                        (TagsRequest,),
                },
                'attribute_map': {
                    'staging_cdb_id': 'stagingCdbId',
                },
                'location_map': {
                    'staging_cdb_id': 'path',
                    'tags_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_staging_cdb_tags
        )

        def __delete_staging_cdb(
            self,
            staging_cdb_id,
            **kwargs
        ):
            """Delete a staging CDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_staging_cdb(staging_cdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                staging_cdb_id (str): The Staging CDB ID.

            Keyword Args:
                delete_staging_cdb_parameters (DeleteStagingCdbParameters): The parameters to delete a staging CDB.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                DeleteStagingCDBResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['staging_cdb_id'] = \
                staging_cdb_id
            return self.call_with_http_info(**kwargs)

        self.delete_staging_cdb = _Endpoint(
            settings={
                'response_type': (DeleteStagingCDBResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/staging-cdbs/{stagingCdbId}/delete',
                'operation_id': 'delete_staging_cdb',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'staging_cdb_id',
                    'delete_staging_cdb_parameters',
                ],
                'required': [
                    'staging_cdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'staging_cdb_id':
                        (str,),
                    'delete_staging_cdb_parameters':
                        (DeleteStagingCdbParameters,),
                },
                'attribute_map': {
                    'staging_cdb_id': 'stagingCdbId',
                },
                'location_map': {
                    'staging_cdb_id': 'path',
                    'delete_staging_cdb_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__delete_staging_cdb
        )

        def __delete_staging_cdb_tags(
            self,
            staging_cdb_id,
            **kwargs
        ):
            """Delete tags for a staging CDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_staging_cdb_tags(staging_cdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                staging_cdb_id (str): The Staging CDB ID.

            Keyword Args:
                delete_tag (DeleteTag): The parameters to delete tags. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['staging_cdb_id'] = \
                staging_cdb_id
            return self.call_with_http_info(**kwargs)

        self.delete_staging_cdb_tags = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/staging-cdbs/{stagingCdbId}/tags/delete',
                'operation_id': 'delete_staging_cdb_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'staging_cdb_id',
                    'delete_tag',
                ],
                'required': [
                    'staging_cdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'staging_cdb_id':
                        (str,),
                    'delete_tag':
                        (DeleteTag,),
                },
                'attribute_map': {
                    'staging_cdb_id': 'stagingCdbId',
                },
                'location_map': {
                    'staging_cdb_id': 'path',
                    'delete_tag': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__delete_staging_cdb_tags
        )

        def __disable_staging_cdb(
            self,
            staging_cdb_id,
            **kwargs
        ):
            """Disable a staging CDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.disable_staging_cdb(staging_cdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                staging_cdb_id (str): The Staging CDB ID.

            Keyword Args:
                disable_cdb_parameters (DisableCDBParameters): The parameters to disable a staging CDB.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                DisableStagingCDBResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['staging_cdb_id'] = \
                staging_cdb_id
            return self.call_with_http_info(**kwargs)

        self.disable_staging_cdb = _Endpoint(
            settings={
                'response_type': (DisableStagingCDBResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/staging-cdbs/{stagingCdbId}/disable',
                'operation_id': 'disable_staging_cdb',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'staging_cdb_id',
                    'disable_cdb_parameters',
                ],
                'required': [
                    'staging_cdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'staging_cdb_id':
                        (str,),
                    'disable_cdb_parameters':
                        (DisableCDBParameters,),
                },
                'attribute_map': {
                    'staging_cdb_id': 'stagingCdbId',
                },
                'location_map': {
                    'staging_cdb_id': 'path',
                    'disable_cdb_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__disable_staging_cdb
        )

        def __enable_staging_cdb(
            self,
            staging_cdb_id,
            **kwargs
        ):
            """Enable a staging CDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.enable_staging_cdb(staging_cdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                staging_cdb_id (str): The Staging CDB ID.

            Keyword Args:
                enable_cdb_parameters (EnableCDBParameters): The parameters to enable a staging CDB.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                EnableStagingCDBResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['staging_cdb_id'] = \
                staging_cdb_id
            return self.call_with_http_info(**kwargs)

        self.enable_staging_cdb = _Endpoint(
            settings={
                'response_type': (EnableStagingCDBResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/staging-cdbs/{stagingCdbId}/enable',
                'operation_id': 'enable_staging_cdb',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'staging_cdb_id',
                    'enable_cdb_parameters',
                ],
                'required': [
                    'staging_cdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'staging_cdb_id':
                        (str,),
                    'enable_cdb_parameters':
                        (EnableCDBParameters,),
                },
                'attribute_map': {
                    'staging_cdb_id': 'stagingCdbId',
                },
                'location_map': {
                    'staging_cdb_id': 'path',
                    'enable_cdb_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__enable_staging_cdb
        )

        def __get_staging_cdb_by_id(
            self,
            staging_cdb_id,
            **kwargs
        ):
            """Get a Staging CDB by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_staging_cdb_by_id(staging_cdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                staging_cdb_id (str): The Staging CDB ID.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                StagingCdb
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['staging_cdb_id'] = \
                staging_cdb_id
            return self.call_with_http_info(**kwargs)

        self.get_staging_cdb_by_id = _Endpoint(
            settings={
                'response_type': (StagingCdb,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/staging-cdbs/{stagingCdbId}',
                'operation_id': 'get_staging_cdb_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'staging_cdb_id',
                ],
                'required': [
                    'staging_cdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'staging_cdb_id':
                        (str,),
                },
                'attribute_map': {
                    'staging_cdb_id': 'stagingCdbId',
                },
                'location_map': {
                    'staging_cdb_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_staging_cdb_by_id
        )

        def __get_staging_cdb_tags(
            self,
            staging_cdb_id,
            **kwargs
        ):
            """Get tags for a staging CDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_staging_cdb_tags(staging_cdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                staging_cdb_id (str): The Staging CDB ID.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['staging_cdb_id'] = \
                staging_cdb_id
            return self.call_with_http_info(**kwargs)

        self.get_staging_cdb_tags = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/staging-cdbs/{stagingCdbId}/tags',
                'operation_id': 'get_staging_cdb_tags',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'staging_cdb_id',
                ],
                'required': [
                    'staging_cdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'staging_cdb_id':
                        (str,),
                },
                'attribute_map': {
                    'staging_cdb_id': 'stagingCdbId',
                },
                'location_map': {
                    'staging_cdb_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_staging_cdb_tags
        )

        def __get_staging_cdbs(
            self,
            **kwargs
        ):
            """List all Staging CDBs.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_staging_cdbs(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListStagingCdbsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_staging_cdbs = _Endpoint(
            settings={
                'response_type': (ListStagingCdbsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/staging-cdbs',
                'operation_id': 'get_staging_cdbs',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name",
                        "DATABASE_NAME": "database_name",
                        "-DATABASE_NAME": "-database_name",
                        "DATABASE_VERSION": "database_version",
                        "-DATABASE_VERSION": "-database_version",
                        "ENVIRONMENT_ID": "environment_id",
                        "-ENVIRONMENT_ID": "-environment_id",
                        "SIZE": "size",
                        "-SIZE": "-size",
                        "JDBC_CONNECTION_STRING": "jdbc_connection_string",
                        "-JDBC_CONNECTION_STRING": "-jdbc_connection_string",
                        "AGENT_ID": "agent_id",
                        "-AGENT_ID": "-agent_id",
                        "NAMESPACE_ID": "namespace_id",
                        "-NAMESPACE_ID": "-namespace_id",
                        "NAMESPACE_NAME": "namespace_name",
                        "-NAMESPACE_NAME": "-namespace_name",
                        "IS_REPLICA": "is_replica",
                        "-IS_REPLICA": "-is_replica",
                        "ENGINE_CONTAINER_REFERENCE": "engine_container_reference",
                        "-ENGINE_CONTAINER_REFERENCE": "-engine_container_reference",
                        "GROUP_NAME": "group_name",
                        "-GROUP_NAME": "-group_name",
                        "ENABLED": "enabled",
                        "-ENABLED": "-enabled",
                        "STATUS": "status",
                        "-STATUS": "-status",
                        "INSTANCE_NAME": "instance_name",
                        "-INSTANCE_NAME": "-instance_name",
                        "INSTANCE_NUMBER": "instance_number",
                        "-INSTANCE_NUMBER": "-instance_number",
                        "REPOSITORY_ID": "repository_id",
                        "-REPOSITORY_ID": "-repository_id",
                        "TDE_KEYSTORE_CONFIG_TYPE": "tde_keystore_config_type",
                        "-TDE_KEYSTORE_CONFIG_TYPE": "-tde_keystore_config_type",
                        "DATABASE_UNIQUE_NAME": "database_unique_name",
                        "-DATABASE_UNIQUE_NAME": "-database_unique_name",
                        "TDE_KMS_PKCS11_CONFIG_PATH": "tde_kms_pkcs11_config_path",
                        "-TDE_KMS_PKCS11_CONFIG_PATH": "-tde_kms_pkcs11_config_path",
                        "IS_TDE_KEYSTORE_PASSWORD_SET": "is_tde_keystore_password_set",
                        "-IS_TDE_KEYSTORE_PASSWORD_SET": "-is_tde_keystore_password_set",
                        "AUTO_STAGING_PUSH_RESTART": "auto_staging_push_restart",
                        "-AUTO_STAGING_PUSH_RESTART": "-auto_staging_push_restart",
                        "CONFIGURE_STAGING_DB_PARAMS": "configure_staging_db_params",
                        "-CONFIGURE_STAGING_DB_PARAMS": "-configure_staging_db_params",
                        "PHYSICAL_STANDBY": "physical_standby",
                        "-PHYSICAL_STANDBY": "-physical_standby",
                        "VALIDATE_SNAPSHOT_BY_OPENING_DB_IN_READ_MODE": "validate_snapshot_by_opening_db_in_read_mode",
                        "-VALIDATE_SNAPSHOT_BY_OPENING_DB_IN_READ_MODE": "-validate_snapshot_by_opening_db_in_read_mode",
                        "MOUNT_BASE": "mount_base",
                        "-MOUNT_BASE": "-mount_base",
                        "DATAFILE_MOUNT_PATH": "datafile_mount_path",
                        "-DATAFILE_MOUNT_PATH": "-datafile_mount_path",
                        "ARCHIVE_MOUNT_PATH": "archive_mount_path",
                        "-ARCHIVE_MOUNT_PATH": "-archive_mount_path",
                        "NFS_VERSION": "nfs_version",
                        "-NFS_VERSION": "-nfs_version",
                        "NFS_VERSION_REASON": "nfs_version_reason",
                        "-NFS_VERSION_REASON": "-nfs_version_reason",
                        "NFS_ENCRYPTION_ENABLED": "nfs_encryption_enabled",
                        "-NFS_ENCRYPTION_ENABLED": "-nfs_encryption_enabled"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_staging_cdbs
        )

        def __search_staging_cdbs(
            self,
            **kwargs
        ):
            """Search for Staging CDBs.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.search_staging_cdbs(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                search_body (SearchBody): A request body containing a filter expression. This enables searching for items matching arbitrarily complex conditions. The list of attributes which can be used in filter expressions is available in the x-filterable vendor extension.  # Filter Expression Overview **Note: All keywords are case-insensitive**  ## Comparison Operators | Operator | Description | Example | | --- | --- | --- | | CONTAINS | Substring or membership testing for string and list attributes respectively. | field3 CONTAINS 'foobar', field4 CONTAINS TRUE  | | IN | Tests if field is a member of a list literal. List can contain a maximum of 100 values | field2 IN ['Goku', 'Vegeta'] | | GE | Tests if a field is greater than or equal to a literal value | field1 GE 1.2e-2 | | GT | Tests if a field is greater than a literal value | field1 GT 1.2e-2 | | LE | Tests if a field is less than or equal to a literal value | field1 LE 9000 | | LT | Tests if a field is less than a literal value | field1 LT 9.02 | | NE | Tests if a field is not equal to a literal value | field1 NE 42 | | EQ | Tests if a field is equal to a literal value | field1 EQ 42 |  ## Search Operator The SEARCH operator filters for items which have any filterable attribute that contains the input string as a substring, comparison is done case-insensitively. This is not restricted to attributes with string values. Specifically `SEARCH '12'` would match an item with an attribute with an integer value of `123`.  ## Logical Operators Ordered by precedence. | Operator | Description | Example | | --- | --- | --- | | NOT | Logical NOT (Right associative) | NOT field1 LE 9000 | | AND | Logical AND (Left Associative) | field1 GT 9000 AND field2 EQ 'Goku' | | OR | Logical OR (Left Associative) | field1 GT 9000 OR field2 EQ 'Goku' |  ## Grouping Parenthesis `()` can be used to override operator precedence.  For example: NOT (field1 LT 1234 AND field2 CONTAINS 'foo')  ## Literal Values | Literal      | Description | Examples | | --- | --- | --- | | Nil | Represents the absence of a value | nil, Nil, nIl, NIL | | Boolean | true/false boolean | true, false, True, False, TRUE, FALSE | | Number | Signed integer and floating point numbers. Also supports scientific notation. | 0, 1, -1, 1.2, 0.35, 1.2e-2, -1.2e+2 | | String | Single or double quoted | \"foo\", \"bar\", \"foo bar\", 'foo', 'bar', 'foo bar' | | Datetime | Formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) | 2018-04-27T18:39:26.397237+00:00 | | List | Comma-separated literals wrapped in square brackets | [0], [0, 1], ['foo', \"bar\"] |  ## Limitations - A maximum of 8 unique identifiers may be used inside a filter expression. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchStagingCdbsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.search_staging_cdbs = _Endpoint(
            settings={
                'response_type': (SearchStagingCdbsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/staging-cdbs/search',
                'operation_id': 'search_staging_cdbs',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                    'search_body',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name",
                        "DATABASE_NAME": "database_name",
                        "-DATABASE_NAME": "-database_name",
                        "DATABASE_VERSION": "database_version",
                        "-DATABASE_VERSION": "-database_version",
                        "ENVIRONMENT_ID": "environment_id",
                        "-ENVIRONMENT_ID": "-environment_id",
                        "SIZE": "size",
                        "-SIZE": "-size",
                        "JDBC_CONNECTION_STRING": "jdbc_connection_string",
                        "-JDBC_CONNECTION_STRING": "-jdbc_connection_string",
                        "AGENT_ID": "agent_id",
                        "-AGENT_ID": "-agent_id",
                        "NAMESPACE_ID": "namespace_id",
                        "-NAMESPACE_ID": "-namespace_id",
                        "NAMESPACE_NAME": "namespace_name",
                        "-NAMESPACE_NAME": "-namespace_name",
                        "IS_REPLICA": "is_replica",
                        "-IS_REPLICA": "-is_replica",
                        "ENGINE_CONTAINER_REFERENCE": "engine_container_reference",
                        "-ENGINE_CONTAINER_REFERENCE": "-engine_container_reference",
                        "GROUP_NAME": "group_name",
                        "-GROUP_NAME": "-group_name",
                        "ENABLED": "enabled",
                        "-ENABLED": "-enabled",
                        "STATUS": "status",
                        "-STATUS": "-status",
                        "INSTANCE_NAME": "instance_name",
                        "-INSTANCE_NAME": "-instance_name",
                        "INSTANCE_NUMBER": "instance_number",
                        "-INSTANCE_NUMBER": "-instance_number",
                        "REPOSITORY_ID": "repository_id",
                        "-REPOSITORY_ID": "-repository_id",
                        "TDE_KEYSTORE_CONFIG_TYPE": "tde_keystore_config_type",
                        "-TDE_KEYSTORE_CONFIG_TYPE": "-tde_keystore_config_type",
                        "DATABASE_UNIQUE_NAME": "database_unique_name",
                        "-DATABASE_UNIQUE_NAME": "-database_unique_name",
                        "TDE_KMS_PKCS11_CONFIG_PATH": "tde_kms_pkcs11_config_path",
                        "-TDE_KMS_PKCS11_CONFIG_PATH": "-tde_kms_pkcs11_config_path",
                        "IS_TDE_KEYSTORE_PASSWORD_SET": "is_tde_keystore_password_set",
                        "-IS_TDE_KEYSTORE_PASSWORD_SET": "-is_tde_keystore_password_set",
                        "AUTO_STAGING_PUSH_RESTART": "auto_staging_push_restart",
                        "-AUTO_STAGING_PUSH_RESTART": "-auto_staging_push_restart",
                        "CONFIGURE_STAGING_DB_PARAMS": "configure_staging_db_params",
                        "-CONFIGURE_STAGING_DB_PARAMS": "-configure_staging_db_params",
                        "PHYSICAL_STANDBY": "physical_standby",
                        "-PHYSICAL_STANDBY": "-physical_standby",
                        "VALIDATE_SNAPSHOT_BY_OPENING_DB_IN_READ_MODE": "validate_snapshot_by_opening_db_in_read_mode",
                        "-VALIDATE_SNAPSHOT_BY_OPENING_DB_IN_READ_MODE": "-validate_snapshot_by_opening_db_in_read_mode",
                        "MOUNT_BASE": "mount_base",
                        "-MOUNT_BASE": "-mount_base",
                        "DATAFILE_MOUNT_PATH": "datafile_mount_path",
                        "-DATAFILE_MOUNT_PATH": "-datafile_mount_path",
                        "ARCHIVE_MOUNT_PATH": "archive_mount_path",
                        "-ARCHIVE_MOUNT_PATH": "-archive_mount_path",
                        "NFS_VERSION": "nfs_version",
                        "-NFS_VERSION": "-nfs_version",
                        "NFS_VERSION_REASON": "nfs_version_reason",
                        "-NFS_VERSION_REASON": "-nfs_version_reason",
                        "NFS_ENCRYPTION_ENABLED": "nfs_encryption_enabled",
                        "-NFS_ENCRYPTION_ENABLED": "-nfs_encryption_enabled"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                    'search_body':
                        (SearchBody,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                    'search_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__search_staging_cdbs
        )



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.deletion_dependency_object import DeletionDependencyObject
from delphix.api.gateway.model.deletion_dependency_prerequisite_action import DeletionDependencyPrerequisiteAction
globals()['DeletionDependencyObject'] = DeletionDependencyObject
globals()['DeletionDependencyPrerequisiteAction'] = DeletionDependencyPrerequisiteAction
from delphix.api.gateway.model.deletion_dependencies_tree_response import DeletionDependenciesTreeResponse


class TestDeletionDependenciesTreeResponse(unittest.TestCase):
    """DeletionDependenciesTreeResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDeletionDependenciesTreeResponse(self):
        """Test DeletionDependenciesTreeResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DeletionDependenciesTreeResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
)
from ..model_utils import OpenApiModel
from delphix.api.gateway.exceptions import ApiAttributeError


def lazy_import():
    from delphix.api.gateway.model.additional_mount_point import AdditionalMountPoint
    from delphix.api.gateway.model.containerization_state_enum import ContainerizationStateEnum
    from delphix.api.gateway.model.mssql_ag_replica import MssqlAgReplica
    from delphix.api.gateway.model.nfs_version_reason_enum import NfsVersionReasonEnum
    from delphix.api.gateway.model.oracle_active_instance import OracleActiveInstance
    from delphix.api.gateway.model.oracle_custom_env_var import OracleCustomEnvVar
    from delphix.api.gateway.model.oracle_rac_database_instance import OracleRACDatabaseInstance
    from delphix.api.gateway.model.oracle_service import OracleService
    from delphix.api.gateway.model.replica import Replica
    from delphix.api.gateway.model.tag import Tag
    from delphix.api.gateway.model.virtual_dataset_hooks import VirtualDatasetHooks
    globals()['AdditionalMountPoint'] = AdditionalMountPoint
    globals()['ContainerizationStateEnum'] = ContainerizationStateEnum
    globals()['MssqlAgReplica'] = MssqlAgReplica
    globals()['NfsVersionReasonEnum'] = NfsVersionReasonEnum
    globals()['OracleActiveInstance'] = OracleActiveInstance
    globals()['OracleCustomEnvVar'] = OracleCustomEnvVar
    globals()['OracleRACDatabaseInstance'] = OracleRACDatabaseInstance
    globals()['OracleService'] = OracleService
    globals()['Replica'] = Replica
    globals()['Tag'] = Tag
    globals()['VirtualDatasetHooks'] = VirtualDatasetHooks


class VDB(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
    }

    validations = {
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'id': (str,),  # noqa: E501
            'database_type': (str, none_type,),  # noqa: E501
            'name': (str, none_type,),  # noqa: E501
            'database_name': (str,),  # noqa: E501
            'namespace_id': (str,),  # noqa: E501
            'namespace_name': (str,),  # noqa: E501
            'is_replica': (bool,),  # noqa: E501
            'is_locked': (bool,),  # noqa: E501
            'locked_by': (int,),  # noqa: E501
            'locked_by_name': (str,),  # noqa: E501
            'database_version': (str, none_type,),  # noqa: E501
            'jdbc_connection_string': (str,),  # noqa: E501
            'size': (int, none_type,),  # noqa: E501
            'storage_size': (int, none_type,),  # noqa: E501
            'unvirtualized_space': (int,),  # noqa: E501
            'engine_id': (str,),  # noqa: E501
            'status': (str, none_type,),  # noqa: E501
            'masked': (bool, none_type,),  # noqa: E501
            'content_type': (str, none_type,),  # noqa: E501
            'parent_timeflow_timestamp': (datetime, none_type,),  # noqa: E501
            'parent_timeflow_timezone': (str, none_type,),  # noqa: E501
            'environment_id': (str, none_type,),  # noqa: E501
            'ip_address': (str, none_type,),  # noqa: E501
            'fqdn': (str, none_type,),  # noqa: E501
            'parent_id': (str, none_type,),  # noqa: E501
            'parent_dsource_id': (str, none_type,),  # noqa: E501
            'root_parent_id': (str, none_type,),  # noqa: E501
            'group_name': (str, none_type,),  # noqa: E501
            'engine_name': (str, none_type,),  # noqa: E501
            'cdb_id': (str, none_type,),  # noqa: E501
            'tags': ([Tag],),  # noqa: E501
            'creation_date': (datetime, none_type,),  # noqa: E501
            'hooks': (VirtualDatasetHooks,),  # noqa: E501
            'appdata_source_params': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type,),  # noqa: E501
            'template_id': (str, none_type,),  # noqa: E501
            'template_name': (str, none_type,),  # noqa: E501
            'config_params': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type,),  # noqa: E501
            'environment_user_ref': (str,),  # noqa: E501
            'additional_mount_points': ([AdditionalMountPoint], none_type,),  # noqa: E501
            'appdata_config_params': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type,),  # noqa: E501
            'mount_point': (str,),  # noqa: E501
            'current_timeflow_id': (str,),  # noqa: E501
            'previous_timeflow_id': (str,),  # noqa: E501
            'last_refreshed_date': (datetime, none_type,),  # noqa: E501
            'vdb_restart': (bool,),  # noqa: E501
            'is_appdata': (bool,),  # noqa: E501
            'exported_data_directory': (str,),  # noqa: E501
            'vcdb_exported_data_directory': (str,),  # noqa: E501
            'toolkit_id': (str,),  # noqa: E501
            'plugin_version': (str, none_type,),  # noqa: E501
            'primary_object_id': (str,),  # noqa: E501
            'primary_engine_id': (str,),  # noqa: E501
            'primary_engine_name': (str,),  # noqa: E501
            'replicas': ([Replica],),  # noqa: E501
            'invoke_datapatch': (bool,),  # noqa: E501
            'enabled': (bool,),  # noqa: E501
            'node_listeners': ([str],),  # noqa: E501
            'instance_name': (str,),  # noqa: E501
            'instance_number': (int,),  # noqa: E501
            'instances': ([OracleRACDatabaseInstance],),  # noqa: E501
            'oracle_services': ([OracleService],),  # noqa: E501
            'repository_id': (str,),  # noqa: E501
            'containerization_state': (ContainerizationStateEnum,),  # noqa: E501
            'parent_tde_keystore_path': (str,),  # noqa: E501
            'target_vcdb_tde_keystore_path': (str,),  # noqa: E501
            'tde_key_identifier': (str,),  # noqa: E501
            'parent_pdb_tde_keystore_path': (str,),  # noqa: E501
            'target_pdb_tde_keystore_path': (str,),  # noqa: E501
            'recovery_model': (str,),  # noqa: E501
            'cdc_on_provision': (bool,),  # noqa: E501
            'data_connection_id': (str,),  # noqa: E501
            'mssql_ag_backup_location': (str,),  # noqa: E501
            'mssql_ag_backup_based': (bool,),  # noqa: E501
            'mssql_ag_replicas': ([MssqlAgReplica],),  # noqa: E501
            'database_unique_name': (str,),  # noqa: E501
            'db_username': (str,),  # noqa: E501
            'new_db_id': (bool,),  # noqa: E501
            'redo_log_groups': (int,),  # noqa: E501
            'redo_log_size_in_mb': (int,),  # noqa: E501
            'custom_env_vars': ([OracleCustomEnvVar],),  # noqa: E501
            'active_instances': ([OracleActiveInstance],),  # noqa: E501
            'nfs_version': (int,),  # noqa: E501
            'nfs_version_reason': (NfsVersionReasonEnum,),  # noqa: E501
            'nfs_encryption_enabled': (bool,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'id': 'id',  # noqa: E501
        'database_type': 'database_type',  # noqa: E501
        'name': 'name',  # noqa: E501
        'database_name': 'database_name',  # noqa: E501
        'namespace_id': 'namespace_id',  # noqa: E501
        'namespace_name': 'namespace_name',  # noqa: E501
        'is_replica': 'is_replica',  # noqa: E501
        'is_locked': 'is_locked',  # noqa: E501
        'locked_by': 'locked_by',  # noqa: E501
        'locked_by_name': 'locked_by_name',  # noqa: E501
        'database_version': 'database_version',  # noqa: E501
        'jdbc_connection_string': 'jdbc_connection_string',  # noqa: E501
        'size': 'size',  # noqa: E501
        'storage_size': 'storage_size',  # noqa: E501
        'unvirtualized_space': 'unvirtualized_space',  # noqa: E501
        'engine_id': 'engine_id',  # noqa: E501
        'status': 'status',  # noqa: E501
        'masked': 'masked',  # noqa: E501
        'content_type': 'content_type',  # noqa: E501
        'parent_timeflow_timestamp': 'parent_timeflow_timestamp',  # noqa: E501
        'parent_timeflow_timezone': 'parent_timeflow_timezone',  # noqa: E501
        'environment_id': 'environment_id',  # noqa: E501
        'ip_address': 'ip_address',  # noqa: E501
        'fqdn': 'fqdn',  # noqa: E501
        'parent_id': 'parent_id',  # noqa: E501
        'parent_dsource_id': 'parent_dsource_id',  # noqa: E501
        'root_parent_id': 'root_parent_id',  # noqa: E501
        'group_name': 'group_name',  # noqa: E501
        'engine_name': 'engine_name',  # noqa: E501
        'cdb_id': 'cdb_id',  # noqa: E501
        'tags': 'tags',  # noqa: E501
        'creation_date': 'creation_date',  # noqa: E501
        'hooks': 'hooks',  # noqa: E501
        'appdata_source_params': 'appdata_source_params',  # noqa: E501
        'template_id': 'template_id',  # noqa: E501
        'template_name': 'template_name',  # noqa: E501
        'config_params': 'config_params',  # noqa: E501
        'environment_user_ref': 'environment_user_ref',  # noqa: E501
        'additional_mount_points': 'additional_mount_points',  # noqa: E501
        'appdata_config_params': 'appdata_config_params',  # noqa: E501
        'mount_point': 'mount_point',  # noqa: E501
        'current_timeflow_id': 'current_timeflow_id',  # noqa: E501
        'previous_timeflow_id': 'previous_timeflow_id',  # noqa: E501
        'last_refreshed_date': 'last_refreshed_date',  # noqa: E501
        'vdb_restart': 'vdb_restart',  # noqa: E501
        'is_appdata': 'is_appdata',  # noqa: E501
        'exported_data_directory': 'exported_data_directory',  # noqa: E501
        'vcdb_exported_data_directory': 'vcdb_exported_data_directory',  # noqa: E501
        'toolkit_id': 'toolkit_id',  # noqa: E501
        'plugin_version': 'plugin_version',  # noqa: E501
        'primary_object_id': 'primary_object_id',  # noqa: E501
        'primary_engine_id': 'primary_engine_id',  # noqa: E501
        'primary_engine_name': 'primary_engine_name',  # noqa: E501
        'replicas': 'replicas',  # noqa: E501
        'invoke_datapatch': 'invoke_datapatch',  # noqa: E501
        'enabled': 'enabled',  # noqa: E501
        'node_listeners': 'node_listeners',  # noqa: E501
        'instance_name': 'instance_name',  # noqa: E501
        'instance_number': 'instance_number',  # noqa: E501
        'instances': 'instances',  # noqa: E501
        'oracle_services': 'oracle_services',  # noqa: E501
        'repository_id': 'repository_id',  # noqa: E501
        'containerization_state': 'containerization_state',  # noqa: E501
        'parent_tde_keystore_path': 'parent_tde_keystore_path',  # noqa: E501
        'target_vcdb_tde_keystore_path': 'target_vcdb_tde_keystore_path',  # noqa: E501
        'tde_key_identifier': 'tde_key_identifier',  # noqa: E501
        'parent_pdb_tde_keystore_path': 'parent_pdb_tde_keystore_path',  # noqa: E501
        'target_pdb_tde_keystore_path': 'target_pdb_tde_keystore_path',  # noqa: E501
        'recovery_model': 'recovery_model',  # noqa: E501
        'cdc_on_provision': 'cdc_on_provision',  # noqa: E501
        'data_connection_id': 'data_connection_id',  # noqa: E501
        'mssql_ag_backup_location': 'mssql_ag_backup_location',  # noqa: E501
        'mssql_ag_backup_based': 'mssql_ag_backup_based',  # noqa: E501
        'mssql_ag_replicas': 'mssql_ag_replicas',  # noqa: E501
        'database_unique_name': 'database_unique_name',  # noqa: E501
        'db_username': 'db_username',  # noqa: E501
        'new_db_id': 'new_db_id',  # noqa: E501
        'redo_log_groups': 'redo_log_groups',  # noqa: E501
        'redo_log_size_in_mb': 'redo_log_size_in_mb',  # noqa: E501
        'custom_env_vars': 'custom_env_vars',  # noqa: E501
        'active_instances': 'active_instances',  # noqa: E501
        'nfs_version': 'nfs_version',  # noqa: E501
        'nfs_version_reason': 'nfs_version_reason',  # noqa: E501
        'nfs_encryption_enabled': 'nfs_encryption_enabled',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, *args, **kwargs):  # noqa: E501
        """VDB - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            id (str): The VDB object entity ID.. [optional]  # noqa: E501
            database_type (str, none_type): The database type of this VDB.. [optional]  # noqa: E501
            name (str, none_type): The logical name of this VDB.. [optional]  # noqa: E501
            database_name (str): The name of the database on the target environment or in the database management system.. [optional]  # noqa: E501
            namespace_id (str): The namespace id of this VDB.. [optional]  # noqa: E501
            namespace_name (str): The namespace name of this VDB.. [optional]  # noqa: E501
            is_replica (bool): Is this a replicated object.. [optional]  # noqa: E501
            is_locked (bool): Is this VDB locked.. [optional]  # noqa: E501
            locked_by (int): The ID of the account that locked this VDB.. [optional]  # noqa: E501
            locked_by_name (str): The name of the account that locked this VDB.. [optional]  # noqa: E501
            database_version (str, none_type): The database version of this VDB.. [optional]  # noqa: E501
            jdbc_connection_string (str): The JDBC connection URL for this VDB.. [optional]  # noqa: E501
            size (int, none_type): The total size of this VDB, in bytes.. [optional]  # noqa: E501
            storage_size (int, none_type): The actual space used by this VDB, in bytes.. [optional]  # noqa: E501
            unvirtualized_space (int): The disk space, in bytes, that it would take to store the VDB without Delphix.. [optional]  # noqa: E501
            engine_id (str): A reference to the Engine that this VDB belongs to.. [optional]  # noqa: E501
            status (str, none_type): The runtime status of the VDB. 'Unknown' if all attempts to connect to the dataset failed.. [optional]  # noqa: E501
            masked (bool, none_type): The VDB is masked or not.. [optional]  # noqa: E501
            content_type (str, none_type): The content type of the vdb.. [optional]  # noqa: E501
            parent_timeflow_timestamp (datetime, none_type): The timestamp for parent timeflow.. [optional]  # noqa: E501
            parent_timeflow_timezone (str, none_type): The timezone for parent timeflow.. [optional]  # noqa: E501
            environment_id (str, none_type): A reference to the Environment that hosts this VDB.. [optional]  # noqa: E501
            ip_address (str, none_type): The IP address of the VDB's host.. [optional]  # noqa: E501
            fqdn (str, none_type): The FQDN of the VDB's host.. [optional]  # noqa: E501
            parent_id (str, none_type): A reference to the parent dataset of this VDB.. [optional]  # noqa: E501
            parent_dsource_id (str, none_type): A reference to the parent dSource of this VDB.. [optional]  # noqa: E501
            root_parent_id (str, none_type): A reference to the root parent dataset of this VDB which could be a VDB or a dSource.. [optional]  # noqa: E501
            group_name (str, none_type): The name of the group containing this VDB.. [optional]  # noqa: E501
            engine_name (str, none_type): Name of the Engine where this VDB is hosted. [optional]  # noqa: E501
            cdb_id (str, none_type): A reference to the CDB or VCDB associated with this VDB.. [optional]  # noqa: E501
            tags ([Tag]): [optional]  # noqa: E501
            creation_date (datetime, none_type): The date this VDB was created.. [optional]  # noqa: E501
            hooks (VirtualDatasetHooks): [optional]  # noqa: E501
            appdata_source_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): The JSON payload conforming to the DraftV4 schema based on the type of application data being manipulated.. [optional]  # noqa: E501
            template_id (str, none_type): A reference to the Database Template.. [optional]  # noqa: E501
            template_name (str, none_type): Name of the Database Template.. [optional]  # noqa: E501
            config_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): Database configuration parameter overrides.. [optional]  # noqa: E501
            environment_user_ref (str): The environment user reference.. [optional]  # noqa: E501
            additional_mount_points ([AdditionalMountPoint], none_type): Specifies additional locations on which to mount a subdirectory of an AppData container. Can only be updated while the VDB is disabled.. [optional]  # noqa: E501
            appdata_config_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): The parameters specified by the source config schema in the toolkit. [optional]  # noqa: E501
            mount_point (str): Mount point for the VDB (Oracle, ASE, AppData).. [optional]  # noqa: E501
            current_timeflow_id (str): A reference to the currently active timeflow for this VDB.. [optional]  # noqa: E501
            previous_timeflow_id (str): A reference to the previous timeflow for this VDB.. [optional]  # noqa: E501
            last_refreshed_date (datetime, none_type): The date this VDB was last refreshed.. [optional]  # noqa: E501
            vdb_restart (bool): Indicates whether the Engine should automatically restart this vdb when target host reboot is detected.. [optional]  # noqa: E501
            is_appdata (bool): Indicates whether this VDB has an AppData database.. [optional]  # noqa: E501
            exported_data_directory (str): ZFS exported data directory path.. [optional]  # noqa: E501
            vcdb_exported_data_directory (str): ZFS exported data directory path of the virtual CDB container (vCDB).. [optional]  # noqa: E501
            toolkit_id (str): The ID of the toolkit associated with this VDB.. [optional]  # noqa: E501
            plugin_version (str, none_type): The version of the plugin associated with this VDB.. [optional]  # noqa: E501
            primary_object_id (str): The ID of the parent object from which replication was done.. [optional]  # noqa: E501
            primary_engine_id (str): The ID of the parent engine from which replication was done.. [optional]  # noqa: E501
            primary_engine_name (str): The name of the parent engine from which replication was done.. [optional]  # noqa: E501
            replicas ([Replica]): The list of replicas replicated from this object.. [optional]  # noqa: E501
            invoke_datapatch (bool): Indicates whether datapatch should be invoked.. [optional]  # noqa: E501
            enabled (bool): True if VDB is enabled false if VDB is disabled.. [optional]  # noqa: E501
            node_listeners ([str]): The list of node listeners for this VDB.. [optional]  # noqa: E501
            instance_name (str): The instance name name of this single instance VDB.. [optional]  # noqa: E501
            instance_number (int): The instance number of this single instance VDB.. [optional]  # noqa: E501
            instances ([OracleRACDatabaseInstance]): [optional]  # noqa: E501
            oracle_services ([OracleService]): [optional]  # noqa: E501
            repository_id (str): The repository id of this VDB.. [optional]  # noqa: E501
            containerization_state (ContainerizationStateEnum): [optional]  # noqa: E501
            parent_tde_keystore_path (str): Path to a copy of the parent's Oracle transparent data encryption keystore on the target host. Required to provision from snapshots containing encrypted database files.. [optional]  # noqa: E501
            target_vcdb_tde_keystore_path (str): Path to the keystore of the target vCDB.. [optional]  # noqa: E501
            tde_key_identifier (str): ID of the key created by Delphix, as recorded in v$encryption_keys.key_id.. [optional]  # noqa: E501
            parent_pdb_tde_keystore_path (str): Path to a copy of the parent PDB's Oracle transparent data encryption keystore on the target host. Required to provision from snapshots of PDB containing encrypted database files with isolated mode keystore. . [optional]  # noqa: E501
            target_pdb_tde_keystore_path (str): Path of the virtual PDB's Oracle transparent data encryption keystore on the target host.. [optional]  # noqa: E501
            recovery_model (str): Recovery model of the vdb database.. [optional]  # noqa: E501
            cdc_on_provision (bool): Whether to enable CDC on provision for MSSql.. [optional]  # noqa: E501
            data_connection_id (str): The ID of the associated DataConnection.. [optional]  # noqa: E501
            mssql_ag_backup_location (str): Shared backup location to be used for VDB provision on AG Cluster.. [optional]  # noqa: E501
            mssql_ag_backup_based (bool): Indicates whether to do fast operations for VDB on AG which will use a healthy secondary replica to recreate the AG or backup based operations which will use the primary replica to recreate the AG using backup and restore process.. [optional]  # noqa: E501
            mssql_ag_replicas ([MssqlAgReplica]): Indicates the mssql replica sources constitutes in MSSQL AG virtual source.. [optional]  # noqa: E501
            database_unique_name (str): The unique name of the database.. [optional]  # noqa: E501
            db_username (str): The user name of the database.. [optional]  # noqa: E501
            new_db_id (bool): Indicates whether Delphix will generate a new DBID during VDB provision or refresh.. [optional]  # noqa: E501
            redo_log_groups (int): Number of Online Redo Log Groups.. [optional]  # noqa: E501
            redo_log_size_in_mb (int): Online Redo Log size in MB.. [optional]  # noqa: E501
            custom_env_vars ([OracleCustomEnvVar]): [optional]  # noqa: E501
            active_instances ([OracleActiveInstance]): [optional]  # noqa: E501
            nfs_version (int): The NFS version that was last used to mount this source.\". [optional]  # noqa: E501
            nfs_version_reason (NfsVersionReasonEnum): [optional]  # noqa: E501
            nfs_encryption_enabled (bool): Flag indicating whether the data transfer is encrypted or not.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, *args, **kwargs):  # noqa: E501
        """VDB - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            id (str): The VDB object entity ID.. [optional]  # noqa: E501
            database_type (str, none_type): The database type of this VDB.. [optional]  # noqa: E501
            name (str, none_type): The logical name of this VDB.. [optional]  # noqa: E501
            database_name (str): The name of the database on the target environment or in the database management system.. [optional]  # noqa: E501
            namespace_id (str): The namespace id of this VDB.. [optional]  # noqa: E501
            namespace_name (str): The namespace name of this VDB.. [optional]  # noqa: E501
            is_replica (bool): Is this a replicated object.. [optional]  # noqa: E501
            is_locked (bool): Is this VDB locked.. [optional]  # noqa: E501
            locked_by (int): The ID of the account that locked this VDB.. [optional]  # noqa: E501
            locked_by_name (str): The name of the account that locked this VDB.. [optional]  # noqa: E501
            database_version (str, none_type): The database version of this VDB.. [optional]  # noqa: E501
            jdbc_connection_string (str): The JDBC connection URL for this VDB.. [optional]  # noqa: E501
            size (int, none_type): The total size of this VDB, in bytes.. [optional]  # noqa: E501
            storage_size (int, none_type): The actual space used by this VDB, in bytes.. [optional]  # noqa: E501
            unvirtualized_space (int): The disk space, in bytes, that it would take to store the VDB without Delphix.. [optional]  # noqa: E501
            engine_id (str): A reference to the Engine that this VDB belongs to.. [optional]  # noqa: E501
            status (str, none_type): The runtime status of the VDB. 'Unknown' if all attempts to connect to the dataset failed.. [optional]  # noqa: E501
            masked (bool, none_type): The VDB is masked or not.. [optional]  # noqa: E501
            content_type (str, none_type): The content type of the vdb.. [optional]  # noqa: E501
            parent_timeflow_timestamp (datetime, none_type): The timestamp for parent timeflow.. [optional]  # noqa: E501
            parent_timeflow_timezone (str, none_type): The timezone for parent timeflow.. [optional]  # noqa: E501
            environment_id (str, none_type): A reference to the Environment that hosts this VDB.. [optional]  # noqa: E501
            ip_address (str, none_type): The IP address of the VDB's host.. [optional]  # noqa: E501
            fqdn (str, none_type): The FQDN of the VDB's host.. [optional]  # noqa: E501
            parent_id (str, none_type): A reference to the parent dataset of this VDB.. [optional]  # noqa: E501
            parent_dsource_id (str, none_type): A reference to the parent dSource of this VDB.. [optional]  # noqa: E501
            root_parent_id (str, none_type): A reference to the root parent dataset of this VDB which could be a VDB or a dSource.. [optional]  # noqa: E501
            group_name (str, none_type): The name of the group containing this VDB.. [optional]  # noqa: E501
            engine_name (str, none_type): Name of the Engine where this VDB is hosted. [optional]  # noqa: E501
            cdb_id (str, none_type): A reference to the CDB or VCDB associated with this VDB.. [optional]  # noqa: E501
            tags ([Tag]): [optional]  # noqa: E501
            creation_date (datetime, none_type): The date this VDB was created.. [optional]  # noqa: E501
            hooks (VirtualDatasetHooks): [optional]  # noqa: E501
            appdata_source_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): The JSON payload conforming to the DraftV4 schema based on the type of application data being manipulated.. [optional]  # noqa: E501
            template_id (str, none_type): A reference to the Database Template.. [optional]  # noqa: E501
            template_name (str, none_type): Name of the Database Template.. [optional]  # noqa: E501
            config_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): Database configuration parameter overrides.. [optional]  # noqa: E501
            environment_user_ref (str): The environment user reference.. [optional]  # noqa: E501
            additional_mount_points ([AdditionalMountPoint], none_type): Specifies additional locations on which to mount a subdirectory of an AppData container. Can only be updated while the VDB is disabled.. [optional]  # noqa: E501
            appdata_config_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): The parameters specified by the source config schema in the toolkit. [optional]  # noqa: E501
            mount_point (str): Mount point for the VDB (Oracle, ASE, AppData).. [optional]  # noqa: E501
            current_timeflow_id (str): A reference to the currently active timeflow for this VDB.. [optional]  # noqa: E501
            previous_timeflow_id (str): A reference to the previous timeflow for this VDB.. [optional]  # noqa: E501
            last_refreshed_date (datetime, none_type): The date this VDB was last refreshed.. [optional]  # noqa: E501
            vdb_restart (bool): Indicates whether the Engine should automatically restart this vdb when target host reboot is detected.. [optional]  # noqa: E501
            is_appdata (bool): Indicates whether this VDB has an AppData database.. [optional]  # noqa: E501
            exported_data_directory (str): ZFS exported data directory path.. [optional]  # noqa: E501
            vcdb_exported_data_directory (str): ZFS exported data directory path of the virtual CDB container (vCDB).. [optional]  # noqa: E501
            toolkit_id (str): The ID of the toolkit associated with this VDB.. [optional]  # noqa: E501
            plugin_version (str, none_type): The version of the plugin associated with this VDB.. [optional]  # noqa: E501
            primary_object_id (str): The ID of the parent object from which replication was done.. [optional]  # noqa: E501
            primary_engine_id (str): The ID of the parent engine from which replication was done.. [optional]  # noqa: E501
            primary_engine_name (str): The name of the parent engine from which replication was done.. [optional]  # noqa: E501
            replicas ([Replica]): The list of replicas replicated from this object.. [optional]  # noqa: E501
            invoke_datapatch (bool): Indicates whether datapatch should be invoked.. [optional]  # noqa: E501
            enabled (bool): True if VDB is enabled false if VDB is disabled.. [optional]  # noqa: E501
            node_listeners ([str]): The list of node listeners for this VDB.. [optional]  # noqa: E501
            instance_name (str): The instance name name of this single instance VDB.. [optional]  # noqa: E501
            instance_number (int): The instance number of this single instance VDB.. [optional]  # noqa: E501
            instances ([OracleRACDatabaseInstance]): [optional]  # noqa: E501
            oracle_services ([OracleService]): [optional]  # noqa: E501
            repository_id (str): The repository id of this VDB.. [optional]  # noqa: E501
            containerization_state (ContainerizationStateEnum): [optional]  # noqa: E501
            parent_tde_keystore_path (str): Path to a copy of the parent's Oracle transparent data encryption keystore on the target host. Required to provision from snapshots containing encrypted database files.. [optional]  # noqa: E501
            target_vcdb_tde_keystore_path (str): Path to the keystore of the target vCDB.. [optional]  # noqa: E501
            tde_key_identifier (str): ID of the key created by Delphix, as recorded in v$encryption_keys.key_id.. [optional]  # noqa: E501
            parent_pdb_tde_keystore_path (str): Path to a copy of the parent PDB's Oracle transparent data encryption keystore on the target host. Required to provision from snapshots of PDB containing encrypted database files with isolated mode keystore. . [optional]  # noqa: E501
            target_pdb_tde_keystore_path (str): Path of the virtual PDB's Oracle transparent data encryption keystore on the target host.. [optional]  # noqa: E501
            recovery_model (str): Recovery model of the vdb database.. [optional]  # noqa: E501
            cdc_on_provision (bool): Whether to enable CDC on provision for MSSql.. [optional]  # noqa: E501
            data_connection_id (str): The ID of the associated DataConnection.. [optional]  # noqa: E501
            mssql_ag_backup_location (str): Shared backup location to be used for VDB provision on AG Cluster.. [optional]  # noqa: E501
            mssql_ag_backup_based (bool): Indicates whether to do fast operations for VDB on AG which will use a healthy secondary replica to recreate the AG or backup based operations which will use the primary replica to recreate the AG using backup and restore process.. [optional]  # noqa: E501
            mssql_ag_replicas ([MssqlAgReplica]): Indicates the mssql replica sources constitutes in MSSQL AG virtual source.. [optional]  # noqa: E501
            database_unique_name (str): The unique name of the database.. [optional]  # noqa: E501
            db_username (str): The user name of the database.. [optional]  # noqa: E501
            new_db_id (bool): Indicates whether Delphix will generate a new DBID during VDB provision or refresh.. [optional]  # noqa: E501
            redo_log_groups (int): Number of Online Redo Log Groups.. [optional]  # noqa: E501
            redo_log_size_in_mb (int): Online Redo Log size in MB.. [optional]  # noqa: E501
            custom_env_vars ([OracleCustomEnvVar]): [optional]  # noqa: E501
            active_instances ([OracleActiveInstance]): [optional]  # noqa: E501
            nfs_version (int): The NFS version that was last used to mount this source.\". [optional]  # noqa: E501
            nfs_version_reason (NfsVersionReasonEnum): [optional]  # noqa: E501
            nfs_encryption_enabled (bool): Flag indicating whether the data transfer is encrypted or not.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.hyperscale_objects_api import HyperscaleObjectsApi  # noqa: E501


class TestHyperscaleObjectsApi(unittest.TestCase):
    """HyperscaleObjectsApi unit test stubs"""

    def setUp(self):
        self.api = HyperscaleObjectsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_hyperscale_connector(self):
        """Test case for create_hyperscale_connector

        Create a Hyperscale Connector.  # noqa: E501
        """
        pass

    def test_create_hyperscale_connector_tags(self):
        """Test case for create_hyperscale_connector_tags

        Create tags for a Hyperscale Connector.  # noqa: E501
        """
        pass

    def test_create_hyperscale_dataset_tags(self):
        """Test case for create_hyperscale_dataset_tags

        Create tags for a Hyperscale Dataset.  # noqa: E501
        """
        pass

    def test_create_hyperscale_mount_point(self):
        """Test case for create_hyperscale_mount_point

        Create a Hyperscale Mount Point  # noqa: E501
        """
        pass

    def test_delete_hyperscale_connector(self):
        """Test case for delete_hyperscale_connector

        Delete a Hyperscale Connector.  # noqa: E501
        """
        pass

    def test_delete_hyperscale_connector_tags(self):
        """Test case for delete_hyperscale_connector_tags

        Delete tags for a Hyperscale Connector.  # noqa: E501
        """
        pass

    def test_delete_hyperscale_dataset_tags(self):
        """Test case for delete_hyperscale_dataset_tags

        Delete tags for a Hyperscale Dataset.  # noqa: E501
        """
        pass

    def test_delete_hyperscale_mount_point(self):
        """Test case for delete_hyperscale_mount_point

        Delete a Hyperscale Mount Point.  # noqa: E501
        """
        pass

    def test_get_hyperscale_connector_by_id(self):
        """Test case for get_hyperscale_connector_by_id

        Get a Hyperscale Connector.  # noqa: E501
        """
        pass

    def test_get_hyperscale_connector_tags(self):
        """Test case for get_hyperscale_connector_tags

        Get tags for a Hyperscale Connector.  # noqa: E501
        """
        pass

    def test_get_hyperscale_connectors(self):
        """Test case for get_hyperscale_connectors

        Returns a list of Hyperscale Connectors.  # noqa: E501
        """
        pass

    def test_get_hyperscale_dataset_by_id(self):
        """Test case for get_hyperscale_dataset_by_id

        Get a Hyperscale Dataset.  # noqa: E501
        """
        pass

    def test_get_hyperscale_dataset_table_or_file_by_id(self):
        """Test case for get_hyperscale_dataset_table_or_file_by_id

        Get a Hyperscale Dataset table or file by ID.  # noqa: E501
        """
        pass

    def test_get_hyperscale_dataset_tables_or_files(self):
        """Test case for get_hyperscale_dataset_tables_or_files

        Get the tables or files of a hyperscale dataset  # noqa: E501
        """
        pass

    def test_get_hyperscale_dataset_tags(self):
        """Test case for get_hyperscale_dataset_tags

        Get tags for a Hyperscale Dataset.  # noqa: E501
        """
        pass

    def test_get_hyperscale_datasets(self):
        """Test case for get_hyperscale_datasets

        Returns a list of Hyperscale Datasets.  # noqa: E501
        """
        pass

    def test_get_hyperscale_mount_point_by_id(self):
        """Test case for get_hyperscale_mount_point_by_id

        Get a Hyperscale Mount Points.  # noqa: E501
        """
        pass

    def test_get_hyperscale_mount_points(self):
        """Test case for get_hyperscale_mount_points

        Returns a list of Hyperscale Mount Points.  # noqa: E501
        """
        pass

    def test_search_hyperscale_connectors(self):
        """Test case for search_hyperscale_connectors

        Search for Hyperscale Connectors.  # noqa: E501
        """
        pass

    def test_search_hyperscale_dataset_tables_or_files(self):
        """Test case for search_hyperscale_dataset_tables_or_files

        Search the tables or files of a hyperscale dataset  # noqa: E501
        """
        pass

    def test_search_hyperscale_datasets(self):
        """Test case for search_hyperscale_datasets

        Search for Hyperscale Datasets.  # noqa: E501
        """
        pass

    def test_search_hyperscale_mount_points(self):
        """Test case for search_hyperscale_mount_points

        Search for Hyperscale Mount Points.  # noqa: E501
        """
        pass

    def test_update_hyperscale_connector_by_id(self):
        """Test case for update_hyperscale_connector_by_id

        Update a Hyperscale Connector by ID.  # noqa: E501
        """
        pass

    def test_update_hyperscale_dataset_by_id(self):
        """Test case for update_hyperscale_dataset_by_id

        Update a Hyperscale Dataset by ID.  # noqa: E501
        """
        pass

    def test_update_hyperscale_dataset_table_or_file_by_id(self):
        """Test case for update_hyperscale_dataset_table_or_file_by_id

        Update a Hyperscale Dataset table or file by ID.  # noqa: E501
        """
        pass

    def test_update_hyperscale_mount_point_by_id(self):
        """Test case for update_hyperscale_mount_point_by_id

        Update a Hyperscale Mount Point by ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.api_client import ApiClient, Endpoint as _Endpoint
from delphix.api.gateway.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from delphix.api.gateway.model.error_response import ErrorResponse
from delphix.api.gateway.model.get_all_llm_gateways_response import GetAllLlmGatewaysResponse
from delphix.api.gateway.model.get_all_llm_models_response import GetAllLlmModelsResponse
from delphix.api.gateway.model.llm_upload_response import LLMUploadResponse
from delphix.api.gateway.model.llm_model import LlmModel


class AiManagementApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __get_all_llm_gateways(
            self,
            **kwargs
        ):
            """Get the details of all available gateways  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_all_llm_gateways(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies a descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                GetAllLlmGatewaysResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_all_llm_gateways = _Endpoint(
            settings={
                'response_type': (GetAllLlmGatewaysResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/ai/management/gateway',
                'operation_id': 'get_all_llm_gateways',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "HOSTNAME": "hostname",
                        "-HOSTNAME": "-hostname"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_all_llm_gateways
        )

        def __get_all_llm_models(
            self,
            **kwargs
        ):
            """Get the details of all available Llm models  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_all_llm_models(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies a descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                GetAllLlmModelsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_all_llm_models = _Endpoint(
            settings={
                'response_type': (GetAllLlmModelsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/ai/management/model',
                'operation_id': 'get_all_llm_models',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_all_llm_models
        )

        def __get_llm_model(
            self,
            model_id,
            **kwargs
        ):
            """Get the details of an LLM model  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_llm_model(model_id, async_req=True)
            >>> result = thread.get()

            Args:
                model_id (str): The id of the LLM model

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                LlmModel
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['model_id'] = \
                model_id
            return self.call_with_http_info(**kwargs)

        self.get_llm_model = _Endpoint(
            settings={
                'response_type': (LlmModel,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/ai/management/model/{modelId}',
                'operation_id': 'get_llm_model',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'model_id',
                ],
                'required': [
                    'model_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'model_id',
                ]
            },
            root_map={
                'validations': {
                    ('model_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'model_id':
                        (str,),
                },
                'attribute_map': {
                    'model_id': 'modelId',
                },
                'location_map': {
                    'model_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_llm_model
        )

        def __upload_model(
            self,
            **kwargs
        ):
            """Upload the model file and register it with Ollama service  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.upload_model(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                orchestrator_id (str): The orchestrator where the model should be installed. This must be \"default\".. [optional] if omitted the server will use the default value of "default"
                file (file_type): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                LLMUploadResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.upload_model = _Endpoint(
            settings={
                'response_type': (LLMUploadResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/ai/management/model/upload',
                'operation_id': 'upload_model',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'orchestrator_id',
                    'file',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'orchestrator_id',
                ]
            },
            root_map={
                'validations': {
                    ('orchestrator_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'orchestrator_id':
                        (str,),
                    'file':
                        (file_type,),
                },
                'attribute_map': {
                    'orchestrator_id': 'orchestratorId',
                    'file': 'file',
                },
                'location_map': {
                    'orchestrator_id': 'query',
                    'file': 'form',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'multipart/form-data'
                ]
            },
            api_client=api_client,
            callable=__upload_model
        )



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.data_connections_api import DataConnectionsApi  # noqa: E501


class TestDataConnectionsApi(unittest.TestCase):
    """DataConnectionsApi unit test stubs"""

    def setUp(self):
        self.api = DataConnectionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_data_connection_tags(self):
        """Test case for create_data_connection_tags

        Create tags for a data connection.  # noqa: E501
        """
        pass

    def test_delete_data_connection_tags(self):
        """Test case for delete_data_connection_tags

        Delete tags for a data connection.  # noqa: E501
        """
        pass

    def test_get_data_connection_by_id(self):
        """Test case for get_data_connection_by_id

        Get a data connection by id.  # noqa: E501
        """
        pass

    def test_get_data_connection_tags(self):
        """Test case for get_data_connection_tags

        Get tags for a data connection.  # noqa: E501
        """
        pass

    def test_get_data_connections(self):
        """Test case for get_data_connections

        Returns a list of data connections.  # noqa: E501
        """
        pass

    def test_get_sub_connections(self):
        """Test case for get_sub_connections

        Get sub-connections for a data connection.  # noqa: E501
        """
        pass

    def test_reassign_sub_connection(self):
        """Test case for reassign_sub_connection

        Reassign a SubConnection to another DataConnection.  # noqa: E501
        """
        pass

    def test_search_data_connections(self):
        """Test case for search_data_connections

        Search for data connections.  # noqa: E501
        """
        pass

    def test_search_sub_connections(self):
        """Test case for search_sub_connections

        Search for sub-connections for a data connections.  # noqa: E501
        """
        pass

    def test_update_data_connection(self):
        """Test case for update_data_connection

        Update a data connection.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.virtualization_faults_api import VirtualizationFaultsApi  # noqa: E501


class TestVirtualizationFaultsApi(unittest.TestCase):
    """VirtualizationFaultsApi unit test stubs"""

    def setUp(self):
        self.api = VirtualizationFaultsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_virtualization_faults_history(self):
        """Test case for get_virtualization_faults_history

        Fetch a list of all virtualization faults  # noqa: E501
        """
        pass

    def test_resolve_all_virtualization_faults(self):
        """Test case for resolve_all_virtualization_faults

        Marks all active faults of an engine that the user has permissions over as resolved.  # noqa: E501
        """
        pass

    def test_resolve_or_ignore_virtualization_faults(self):
        """Test case for resolve_or_ignore_virtualization_faults

        Marks selected faults as resolved or ignored.  # noqa: E501
        """
        pass

    def test_resolve_virtualization_fault(self):
        """Test case for resolve_virtualization_fault

        Marks the fault as resolved. The Delphix engine will attempt to automatically detect cases where the fault has been resolved; but this is not always possible and may only occur on periodic intervals. In these cases, the user can proactively mark the fault resolved. This does not change the underlying disposition of the fault - if the problem is still present the system may immediately diagnose the same problem again. This should only be used to notify the system of resolution after the underlying problem has been resolved.  # noqa: E501
        """
        pass

    def test_search_virtualization_faults_history(self):
        """Test case for search_virtualization_faults_history

        Search virtualization faults  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.database_table_metadata import DatabaseTableMetadata


class TestDatabaseTableMetadata(unittest.TestCase):
    """DatabaseTableMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDatabaseTableMetadata(self):
        """Test DatabaseTableMetadata"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DatabaseTableMetadata()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.data_layouts_api import DataLayoutsApi  # noqa: E501


class TestDataLayoutsApi(unittest.TestCase):
    """DataLayoutsApi unit test stubs"""

    def setUp(self):
        self.api = DataLayoutsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_convert_and_drop_bookmarks(self):
        """Test case for convert_and_drop_bookmarks

        Convert and drop engine bookmarks and vdb groups for the data-layout.  # noqa: E501
        """
        pass

    def test_create_data_layout_tags(self):
        """Test case for create_data_layout_tags

        Create tags for a data-layout.  # noqa: E501
        """
        pass

    def test_delete_data_layout_tags(self):
        """Test case for delete_data_layout_tags

        Delete tags for a data-layout.  # noqa: E501
        """
        pass

    def test_get_data_layout_by_id(self):
        """Test case for get_data_layout_by_id

        Get a data-layout by ID.  # noqa: E501
        """
        pass

    def test_get_data_layout_tags(self):
        """Test case for get_data_layout_tags

        Get tags for a data-layout.  # noqa: E501
        """
        pass

    def test_get_data_layouts(self):
        """Test case for get_data_layouts

        List all data-layout (Self-Service Container/Template).  # noqa: E501
        """
        pass

    def test_import_engine_accounts(self):
        """Test case for import_engine_accounts

        Import engine (self-service) accounts.  # noqa: E501
        """
        pass

    def test_search_data_layouts(self):
        """Test case for search_data_layouts

        Search for data-layouts.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.authorization_api import AuthorizationApi  # noqa: E501


class TestAuthorizationApi(unittest.TestCase):
    """AuthorizationApi unit test stubs"""

    def setUp(self):
        self.api = AuthorizationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_access_group_account_ids(self):
        """Test case for add_access_group_account_ids

        Add account ids to an Access group  # noqa: E501
        """
        pass

    def test_add_access_group_account_tags(self):
        """Test case for add_access_group_account_tags

        Add account tags to an Access group  # noqa: E501
        """
        pass

    def test_add_access_group_scopes(self):
        """Test case for add_access_group_scopes

        Add scopes to an Access group  # noqa: E501
        """
        pass

    def test_add_always_allowed_permissions(self):
        """Test case for add_always_allowed_permissions

        Add always allowed permissions for given object type.  # noqa: E501
        """
        pass

    def test_add_objects_to_access_group_scope(self):
        """Test case for add_objects_to_access_group_scope

        Add objects to the access group scope.  # noqa: E501
        """
        pass

    def test_add_role_permissions(self):
        """Test case for add_role_permissions

        Add permissions to a role.  # noqa: E501
        """
        pass

    def test_add_role_ui_profiles(self):
        """Test case for add_role_ui_profiles

        Add UI profiles to a role.  # noqa: E501
        """
        pass

    def test_add_tags_to_scope(self):
        """Test case for add_tags_to_scope

        Add object tags to the access group scope.  # noqa: E501
        """
        pass

    def test_create_access_group(self):
        """Test case for create_access_group

        Create a new access group.  # noqa: E501
        """
        pass

    def test_create_role(self):
        """Test case for create_role

        Create custom role  # noqa: E501
        """
        pass

    def test_create_role_tags(self):
        """Test case for create_role_tags

        Create tags for a role.  # noqa: E501
        """
        pass

    def test_delete_access_group(self):
        """Test case for delete_access_group

        Delete an Access group.  # noqa: E501
        """
        pass

    def test_delete_access_group_scope_object_tags(self):
        """Test case for delete_access_group_scope_object_tags

        Remove tags from the access group scope.  # noqa: E501
        """
        pass

    def test_delete_access_group_scope_objects(self):
        """Test case for delete_access_group_scope_objects

        Remove objects from the access group scope.  # noqa: E501
        """
        pass

    def test_delete_role(self):
        """Test case for delete_role

        Delete role by ID.  # noqa: E501
        """
        pass

    def test_delete_role_tag(self):
        """Test case for delete_role_tag

        Delete tags for a Role.  # noqa: E501
        """
        pass

    def test_delete_role_ui_profiles(self):
        """Test case for delete_role_ui_profiles

        Delete UI profiles from a Role.  # noqa: E501
        """
        pass

    def test_get_access_group_by_id(self):
        """Test case for get_access_group_by_id

        Returns an Access group by ID.  # noqa: E501
        """
        pass

    def test_get_access_group_scope(self):
        """Test case for get_access_group_scope

        Get access group scope.  # noqa: E501
        """
        pass

    def test_get_access_groups(self):
        """Test case for get_access_groups

        List all access groups.  # noqa: E501
        """
        pass

    def test_get_all_object_permissions(self):
        """Test case for get_all_object_permissions

        Returns all of the possible permissions for all of the objects.  # noqa: E501
        """
        pass

    def test_get_object_permissions(self):
        """Test case for get_object_permissions

        Returns permissions for given object.  # noqa: E501
        """
        pass

    def test_get_role_by_id(self):
        """Test case for get_role_by_id

        Returns role by ID.  # noqa: E501
        """
        pass

    def test_get_role_tags(self):
        """Test case for get_role_tags

        Get tags for a Role.  # noqa: E501
        """
        pass

    def test_get_roles(self):
        """Test case for get_roles

        List all roles  # noqa: E501
        """
        pass

    def test_remove_access_group_account_id(self):
        """Test case for remove_access_group_account_id

        Remove the account from the access group.  # noqa: E501
        """
        pass

    def test_remove_access_group_account_tags(self):
        """Test case for remove_access_group_account_tags

        Remove account tags from an access group.  # noqa: E501
        """
        pass

    def test_remove_access_group_scope(self):
        """Test case for remove_access_group_scope

        Remove the scope from the Access group.  # noqa: E501
        """
        pass

    def test_remove_always_allowed_permissions(self):
        """Test case for remove_always_allowed_permissions

        Remove always allowed permissions for given object type.  # noqa: E501
        """
        pass

    def test_remove_role_permissions(self):
        """Test case for remove_role_permissions

        Remove permissions from a role.  # noqa: E501
        """
        pass

    def test_search_access_groups(self):
        """Test case for search_access_groups

        Search for access groups.  # noqa: E501
        """
        pass

    def test_search_roles(self):
        """Test case for search_roles

        Search for roles.  # noqa: E501
        """
        pass

    def test_update_access_group(self):
        """Test case for update_access_group

        Update an Access group.  # noqa: E501
        """
        pass

    def test_update_access_group_scope(self):
        """Test case for update_access_group_scope

        Update access group scope.  # noqa: E501
        """
        pass

    def test_update_role(self):
        """Test case for update_role

        Update a Role.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.additional_mount_point import AdditionalMountPoint
from delphix.api.gateway.model.cluster_node_instance import ClusterNodeInstance
from delphix.api.gateway.model.config_settings_stg import ConfigSettingsStg
from delphix.api.gateway.model.oracle_rac_custom_env_file import OracleRacCustomEnvFile
from delphix.api.gateway.model.oracle_rac_custom_env_var import OracleRacCustomEnvVar
from delphix.api.gateway.model.oracle_tde_keystore_config_type_enum import OracleTdeKeystoreConfigTypeEnum
from delphix.api.gateway.model.tag import Tag
globals()['AdditionalMountPoint'] = AdditionalMountPoint
globals()['ClusterNodeInstance'] = ClusterNodeInstance
globals()['ConfigSettingsStg'] = ConfigSettingsStg
globals()['OracleRacCustomEnvFile'] = OracleRacCustomEnvFile
globals()['OracleRacCustomEnvVar'] = OracleRacCustomEnvVar
globals()['OracleTdeKeystoreConfigTypeEnum'] = OracleTdeKeystoreConfigTypeEnum
globals()['Tag'] = Tag
from delphix.api.gateway.model.base_provision_vdb_parameters_all_of import BaseProvisionVDBParametersAllOf


class TestBaseProvisionVDBParametersAllOf(unittest.TestCase):
    """BaseProvisionVDBParametersAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testBaseProvisionVDBParametersAllOf(self):
        """Test BaseProvisionVDBParametersAllOf"""
        # FIXME: construct object with mandatory attributes with example values
        # model = BaseProvisionVDBParametersAllOf()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.namespace_api import NamespaceApi  # noqa: E501


class TestNamespaceApi(unittest.TestCase):
    """NamespaceApi unit test stubs"""

    def setUp(self):
        self.api = NamespaceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_commit_failover_namespace(self):
        """Test case for commit_failover_namespace

        Commits the failover of a given namespace and discards the failback state.  # noqa: E501
        """
        pass

    def test_delete_namespace(self):
        """Test case for delete_namespace

        Delete a Namespace.  # noqa: E501
        """
        pass

    def test_discard_namespace(self):
        """Test case for discard_namespace

        Discards any partial receive state for the given namespace.  # noqa: E501
        """
        pass

    def test_failback_namespace(self):
        """Test case for failback_namespace

        Initiates failback for the given namespace.  # noqa: E501
        """
        pass

    def test_failover_namespace(self):
        """Test case for failover_namespace

        Initiates failover for the given namespace.  # noqa: E501
        """
        pass

    def test_get_namespace_by_id(self):
        """Test case for get_namespace_by_id

        Get a namespace.  # noqa: E501
        """
        pass

    def test_list_namespaces(self):
        """Test case for list_namespaces

        List all namespaces.  # noqa: E501
        """
        pass

    def test_search_namespaces(self):
        """Test case for search_namespaces

        Search Namespaces.  # noqa: E501
        """
        pass

    def test_update_namespace(self):
        """Test case for update_namespace

        Update a Namespace.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.discovery_policies_api import DiscoveryPoliciesApi  # noqa: E501


class TestDiscoveryPoliciesApi(unittest.TestCase):
    """DiscoveryPoliciesApi unit test stubs"""

    def setUp(self):
        self.api = DiscoveryPoliciesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_discovery_policy_tags(self):
        """Test case for create_discovery_policy_tags

        Create tags for a discovery policy.  # noqa: E501
        """
        pass

    def test_delete_discovery_policy_tags(self):
        """Test case for delete_discovery_policy_tags

        Delete tags for a discovery policy.  # noqa: E501
        """
        pass

    def test_get_discovery_policies(self):
        """Test case for get_discovery_policies

        Retrieve discovery policies.  # noqa: E501
        """
        pass

    def test_get_discovery_policy_by_id(self):
        """Test case for get_discovery_policy_by_id

        Get a discovery policy by ID.  # noqa: E501
        """
        pass

    def test_get_discovery_policy_classifiers(self):
        """Test case for get_discovery_policy_classifiers

        Get classifiers for a discovery policy.  # noqa: E501
        """
        pass

    def test_get_discovery_policy_expressions(self):
        """Test case for get_discovery_policy_expressions

        Get discovery expressions for a discovery policy.  # noqa: E501
        """
        pass

    def test_get_discovery_policy_tags(self):
        """Test case for get_discovery_policy_tags

        Get tags for a discovery policy.  # noqa: E501
        """
        pass

    def test_search_discovery_policies(self):
        """Test case for search_discovery_policies

        Search for discovery policies.  # noqa: E501
        """
        pass

    def test_search_discovery_policy_classifiers(self):
        """Test case for search_discovery_policy_classifiers

        Search for classifiers of a discovery policy.  # noqa: E501
        """
        pass

    def test_search_discovery_policy_expressions(self):
        """Test case for search_discovery_policy_expressions

        Search for discovery expressions of a discovery policy.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.d_sources_api import DSourcesApi  # noqa: E501


class TestDSourcesApi(unittest.TestCase):
    """DSourcesApi unit test stubs"""

    def setUp(self):
        self.api = DSourcesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_attach_mssql_database(self):
        """Test case for attach_mssql_database

        Attaches a MSSql source to a previously detached dsource.  # noqa: E501
        """
        pass

    def test_attach_mssql_staging_push_database(self):
        """Test case for attach_mssql_staging_push_database

        Attaches a MSSql staging push database to a previously detached dsource.  # noqa: E501
        """
        pass

    def test_attach_oracle_dsource(self):
        """Test case for attach_oracle_dsource

        Attach an Oracle dSource to an Oracle database.  # noqa: E501
        """
        pass

    def test_create_tags_dsource(self):
        """Test case for create_tags_dsource

        Create tags for a dSource.  # noqa: E501
        """
        pass

    def test_delete_dsource(self):
        """Test case for delete_dsource

        Delete the specified dSource.  # noqa: E501
        """
        pass

    def test_delete_tags_dsource(self):
        """Test case for delete_tags_dsource

        Delete tags for a dSource.  # noqa: E501
        """
        pass

    def test_detach_mssql_database(self):
        """Test case for detach_mssql_database

        Detaches a linked source from a MSSql database.  # noqa: E501
        """
        pass

    def test_detach_oracle_dsource(self):
        """Test case for detach_oracle_dsource

        Detaches an Oracle source from an Oracle database.  # noqa: E501
        """
        pass

    def test_disable_dsource(self):
        """Test case for disable_dsource

        Disable a dSource.  # noqa: E501
        """
        pass

    def test_enable_dsource(self):
        """Test case for enable_dsource

        Enable a dSource.  # noqa: E501
        """
        pass

    def test_export_dsource_by_location(self):
        """Test case for export_dsource_by_location

        Export a dSource using timeflow location to a physical file system.  # noqa: E501
        """
        pass

    def test_export_dsource_by_snapshot(self):
        """Test case for export_dsource_by_snapshot

        Export a dSource using snapshot to a physical file system  # noqa: E501
        """
        pass

    def test_export_dsource_by_timestamp(self):
        """Test case for export_dsource_by_timestamp

        Export a dSource using timestamp to a physical file system.  # noqa: E501
        """
        pass

    def test_export_dsource_from_bookmark(self):
        """Test case for export_dsource_from_bookmark

        Export a dSource using bookmark to physical file system  # noqa: E501
        """
        pass

    def test_export_dsource_to_asm_by_bookmark(self):
        """Test case for export_dsource_to_asm_by_bookmark

        Export a dSource using bookmark to an ASM file system  # noqa: E501
        """
        pass

    def test_export_dsource_to_asm_by_location(self):
        """Test case for export_dsource_to_asm_by_location

        Export a dSource using SCN to an ASM file system  # noqa: E501
        """
        pass

    def test_export_dsource_to_asm_by_snapshot(self):
        """Test case for export_dsource_to_asm_by_snapshot

        Export a dSource by a snapshot to an ASM file system  # noqa: E501
        """
        pass

    def test_export_dsource_to_asm_by_timestamp(self):
        """Test case for export_dsource_to_asm_by_timestamp

        Export a dSource using timestamp to an ASM file system  # noqa: E501
        """
        pass

    def test_get_appdata_dsource_linking_defaults(self):
        """Test case for get_appdata_dsource_linking_defaults

        Get defaults for an AppData dSource linking.  # noqa: E501
        """
        pass

    def test_get_ase_dsource_linking_defaults(self):
        """Test case for get_ase_dsource_linking_defaults

        Get defaults for an ASE dSource linking.  # noqa: E501
        """
        pass

    def test_get_dsource_by_id(self):
        """Test case for get_dsource_by_id

        Get a dSource by ID.  # noqa: E501
        """
        pass

    def test_get_dsource_deletion_dependencies(self):
        """Test case for get_dsource_deletion_dependencies

        Get deletion dependencies for a dSource.  # noqa: E501
        """
        pass

    def test_get_dsource_snapshots(self):
        """Test case for get_dsource_snapshots

        List Snapshots for a dSource.  # noqa: E501
        """
        pass

    def test_get_dsources(self):
        """Test case for get_dsources

        List all dSources.  # noqa: E501
        """
        pass

    def test_get_mssql_dsource_linking_defaults(self):
        """Test case for get_mssql_dsource_linking_defaults

        Get defaults for a MSSql dSource linking.  # noqa: E501
        """
        pass

    def test_get_mssql_staging_push_dsource_linking_defaults(self):
        """Test case for get_mssql_staging_push_dsource_linking_defaults

        Get defaults for a MSSql staging push dSource linking.  # noqa: E501
        """
        pass

    def test_get_oracle_dsource_linking_defaults(self):
        """Test case for get_oracle_dsource_linking_defaults

        Get defaults for dSource linking.  # noqa: E501
        """
        pass

    def test_get_oracle_staging_push_dsource_linking_defaults(self):
        """Test case for get_oracle_staging_push_dsource_linking_defaults

        Get defaults for a Oracle staging push dSource linking.  # noqa: E501
        """
        pass

    def test_get_tags_dsource(self):
        """Test case for get_tags_dsource

        Get tags for a dSource.  # noqa: E501
        """
        pass

    def test_get_upgrade_compatible_repo_for_dsource(self):
        """Test case for get_upgrade_compatible_repo_for_dsource

        Returns a list of compatible repositories for dSource upgrade.  # noqa: E501
        """
        pass

    def test_link_appdata_database(self):
        """Test case for link_appdata_database

        Link an AppData database as dSource.  # noqa: E501
        """
        pass

    def test_link_ase_database(self):
        """Test case for link_ase_database

        Link an ASE database as dSource.  # noqa: E501
        """
        pass

    def test_link_mssql_database(self):
        """Test case for link_mssql_database

        Link a MSSql database as dSource.  # noqa: E501
        """
        pass

    def test_link_mssql_staging_push_database(self):
        """Test case for link_mssql_staging_push_database

        Link a MSSql staging push database as dSource.  # noqa: E501
        """
        pass

    def test_link_oracle_database(self):
        """Test case for link_oracle_database

        Link Oracle database as dSource.  # noqa: E501
        """
        pass

    def test_link_oracle_staging_push_database(self):
        """Test case for link_oracle_staging_push_database

        Link an Oracle staging push database as dSource.  # noqa: E501
        """
        pass

    def test_search_dsources(self):
        """Test case for search_dsources

        Search for dSources.  # noqa: E501
        """
        pass

    def test_snapshot_dsource(self):
        """Test case for snapshot_dsource

        Snapshot a dSource.  # noqa: E501
        """
        pass

    def test_update_appdata_dsource_by_id(self):
        """Test case for update_appdata_dsource_by_id

        Update values of an AppData dSource  # noqa: E501
        """
        pass

    def test_update_ase_dsource_by_id(self):
        """Test case for update_ase_dsource_by_id

        Update values of an ASE dSource  # noqa: E501
        """
        pass

    def test_update_mssql_dsource_by_id(self):
        """Test case for update_mssql_dsource_by_id

        Update values of an MSSql dSource  # noqa: E501
        """
        pass

    def test_update_oracle_dsource_by_id(self):
        """Test case for update_oracle_dsource_by_id

        Update values of an Oracle dSource  # noqa: E501
        """
        pass

    def test_upgrade_dsource(self):
        """Test case for upgrade_dsource

        Upgrade dSource  # noqa: E501
        """
        pass

    def test_upgrade_oracle_dsource(self):
        """Test case for upgrade_oracle_dsource

        Upgrade the requested Oracle dSource installation and user.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
